@@ -21,8 +21,12 @@ class GmapsAdmin(admin.ModelAdmin):
     list_filter = ('continent',)
     search_fields = ('geoaddress', 'continent', 'country', 'city', 'address', 'zip_code')
     fieldsets = (
-        (None, {'fields': (('continent', 'country'), ('area', 'city',),
-                           ('address', 'zip_code'), ('geoaddress',), ('geolocation',))}),
+        ('Cane', {
+            'fields': (
+                ('continent', 'country'), ('area', 'city',),
+                ('address', 'zip_code'), ('geoaddress',), ('geolocation',)
+            ),
+        }),
     )
     formfield_overrides = {
         AddressField: {'widget': GoogleMapsAddressWidget},
